@@ -168,7 +168,7 @@ def fix_py2_strings(value):
     """ REMOVE ON PYTHON 3 """
     if isinstance(value, six.string_types):
         if not isinstance(value, six.text_type):
-            value = value.replace("\xc0?", "").decode("utf-8")
+            value = value.replace("\xc0?", "").decode("utf-8", "ignore")
         return fix_text(value)
     if isinstance(value, list):
         return list(map(fix_py2_strings, value))
@@ -183,7 +183,7 @@ def encode_strings_for_attachments(value):
     and not utf-8
     """
     if isinstance(value, six.string_types):
-        return value.encode("ISO-8859-1")
+        return value.encode("ISO-8859-1", "ignore")
     if isinstance(value, list):
         return list(map(encode_strings_for_attachments, value))
     if isinstance(value, tuple):
